;;; oni-company.el --- Company configuration         -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2019.0904.210401
;; Package-Requires: (company company-posframe diminish)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration for `company-mode'.

;;; Code:

(require 'company)
(require 'company-dabbrev)
(require 'company-posframe)
(require 'diminish)

(defun oni-company--enable-posframe (_)
  "Enable posframe and remove this function from the hook."
  (when (display-graphic-p)
    (company-posframe-mode)
    (remove-hook 'company-completion-started-hook
                 'oni-company--enable-posframe)))

(setq company-dabbrev-ignore-case nil)
(setq company-idle-delay 0.2)
(setq company-tooltip-align-annotations t)

(setq company-frontends
      '(company-pseudo-tooltip-unless-just-one-frontend
        company-echo-metadata-frontend
        company-preview-frontend))

(add-hook 'company-completion-started-hook 'oni-company--enable-posframe)

(diminish 'company-mode)
(diminish 'company-posframe-mode)

;;;###autoload(with-eval-after-load 'company (require 'oni-company))

(provide 'oni-company)
;;; oni-company.el ends here
