;;; oni-elisp.el --- Emacs Lisp configuration        -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2019.1210.225238
;; Package-Requires: (oni-company oni-flycheck oni-paredit oni-fci oni-yasnippet rainbow-delimiters nameless erefactor)

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <https://www.gnu.org/licenses/>.

;;; Commentary:

;; My configuration for working in Emacs Lisp.

;;; Code:

(require 'yasnippet)

(let ((byte-compile-not-obsolete-funcs '(preceding-sexp)))
  (require 'erefactor))

(require 'ielm)

(defconst oni-elisp-root
  (file-name-directory
   (or load-file-name
       (buffer-file-name)))
  "The directory where ‘oni-elisp’ was loaded from.")

(defconst oni-elisp-snippets-dir
  (expand-file-name "snippets" oni-elisp-root)
  "The directory where ‘oni-elisp’ stores its snippets.")

;;;###autoload
(defun oni-elisp-snippets-initialize ()
  "Initialize the snippets for ‘oni-elisp’."
  (when (boundp 'yas-snippet-dirs)
    (add-to-list 'yas-snippet-dirs oni-elisp-snippets-dir t))
  (yas-load-directory oni-elisp-snippets-dir))

(defun oni-elisp--auto-fill-mode ()
  "Enable ‘auto-fill-mode’ only for comments."
  (setq-local comment-auto-fill-only-comments t)
  (auto-fill-mode))

(add-hook 'emacs-lisp-mode-hook 'company-mode)
(add-hook 'emacs-lisp-mode-hook 'electric-quote-local-mode)
(add-hook 'emacs-lisp-mode-hook 'erefactor-lazy-highlight-turn-on)
(add-hook 'emacs-lisp-mode-hook 'fci-mode)
(add-hook 'emacs-lisp-mode-hook 'flycheck-mode)
(add-hook 'emacs-lisp-mode-hook 'nameless-mode)
(add-hook 'emacs-lisp-mode-hook 'paredit-mode)
(add-hook 'emacs-lisp-mode-hook 'rainbow-delimiters-mode)
(add-hook 'emacs-lisp-mode-hook 'oni-elisp--auto-fill-mode)

(add-hook 'ielm-mode-hook 'company-mode)
(add-hook 'ielm-mode-hook 'paredit-mode)

(setq ielm-prompt "λ> ")

(define-key emacs-lisp-mode-map (kbd "C-c r") erefactor-map)

;;;###autoload
(add-to-list 'auto-mode-alist '("/Cask\\'" . emacs-lisp-mode))

(add-to-list 'display-buffer-alist
             '("\\`\\*ielm\\*\\'" display-buffer-in-side-window
               (side . bottom)
               (slot . 0)
               (window-height . 0.33)))

;;;###autoload
(with-eval-after-load 'elisp-mode
  (with-eval-after-load 'yasnippet
    (oni-elisp-snippets-initialize)))

;;;###autoload(with-eval-after-load 'elisp-mode (require 'oni-elisp))
;;;###autoload(with-eval-after-load 'ielm (require 'oni-elisp))

(provide 'oni-elisp)
;;; oni-elisp.el ends here
